# psdist

This repository is a collection of analysis and visualization methods for six-dimensional position-momentum space (phase space) distributions.


## Installation

https://pypi.org/project/psdist/


## Examples

Some examples in accelerator physics that use methods from this repository:
* https://journals.aps.org/prab/abstract/10.1103/PhysRevAccelBeams.23.124201
* https://arxiv.org/abs/2301.04178

Each subplot in the figure below shows the measured $x-p_x$ distribution of a hadron beam within a small box in $y-p_y-p_z$ space; $y$ varies along the columns, $p_y$ varies along the rows, and $p_z$ varies with the animation frame number.

![](examples/figures/view_yyp_slice_xxp_wslice.gif)
